#!/usr/bin/env perl

use v5.30.0;

use strict;
use warnings;

use Test::Most tests => 1;

use Peace::Test::Mock::Model::Developer;
use Peace::Model::Application;
use Peace::Model::Release;

{
    my $developer   = Peace::Test::Mock::Model::Developer->new;
    my $application = Peace::Model::Application->new(
        name        => 'OpenMG',
        description => 'Stub',
        url => 'https://gitea.sergiotarxz.freemyip.com/sergiotarxz/mangareader',
        developer => $developer,
        app_id    => 'me.sergiotarxz.openmg',
        price     => '99',
        git_repo  =>
          'https://gitea.sergiotarxz.freemyip.com/sergiotarxz/mangareader',
        flatpak_builder_file => 'me.sergiotarxz.openmg.json',
        flatpak_repo => 'https://nightly.gnome.org/gnome-nightly.flatpakrepo',
        verified     => 1,
    );
    my $uuid    = 'random-uuid';
    my $release = Peace::Model::Release->new(
        uuid        => $uuid,
        application => $application,
        tag         => 'main',
        name        => 'test',
    );
    my $build = $release->generate_build( arch => 'aarch64' );
    ok $build->success, 'Build ends successfully.';
}
